@@ -4,14 +4,14 @@
 ( cd opt/kde/share/doc/HTML/fr/kdf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kdm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kig ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ktuberling ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/amor ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/amor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/karm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kate ; rm -rf common )
@@ -20,8 +20,12 @@
 ( cd opt/kde/share/doc/HTML/fr/kdat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kdvi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kgeo ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kget ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kgpg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kmag ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmid ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmix ; rm -rf common )
@@ -32,6 +36,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kolf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kpdf ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/korn ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kppp ; rm -rf common )
@@ -46,6 +52,8 @@
 ( cd opt/kde/share/doc/HTML/fr/ksim ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/lisa ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kxkb ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kalzium ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/katomic ; rm -rf common )
@@ -78,6 +86,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kdesu ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcron ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kdict ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kfind ; rm -rf common )
@@ -110,18 +120,28 @@
 ( cd opt/kde/share/doc/HTML/fr/kwin4 ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/lskat ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/klipper ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kmousetool ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kompare ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kontact ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/konsole ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpackage ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/khelpcenter/faq ; rm -rf common )
@@ -144,12 +164,20 @@
 ( cd opt/kde/share/doc/HTML/fr/konquest ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/panelappearance ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kverbos ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kwallet ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kweather ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmenuedit ; rm -rf common )
@@ -160,8 +188,6 @@
 ( cd opt/kde/share/doc/HTML/fr/flashkard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/aktion ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/aktion ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kxconfig ; rm -rf common )
@@ -202,6 +228,8 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doxygen.css )
@@ -216,12 +244,16 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf fdl-license.html )
@@ -296,6 +328,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/passwords ; rm -rf common )
@@ -358,8 +392,6 @@
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/crashes ; rm -rf common )
@@ -382,6 +414,8 @@
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/uachanger ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/mediaplayer ; rm -rf common )
@@ -390,16 +424,18 @@
 ( cd opt/kde/share/doc/HTML/fr/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbabel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kalarm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kalarm ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kamera ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kdeprint ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kasteroids ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kbruch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/keduca ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kgamma ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kicker ; rm -rf common )
@@ -408,6 +444,8 @@
 ( cd opt/kde/share/doc/HTML/fr/klines ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmines ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kmouth ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmplot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/knotes ; rm -rf common )
@@ -416,6 +454,10 @@
 ( cd opt/kde/share/doc/HTML/fr/kpager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpaint ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kopete ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kpilot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kpilot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kpoker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kruler ; rm -rf common )
@@ -434,12 +476,12 @@
 ( cd opt/kde/share/doc/HTML/fr/ktouch ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kwrite ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/megami ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kreversi ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/noatun ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/ksplashml ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kblackbox ; rm -rf common )
@@ -454,8 +496,6 @@
 ( cd opt/kde/share/doc/HTML/fr/klettres ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kaphorism ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kghostview ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/klickety ; rm -rf common )
@@ -466,6 +506,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kenolaba ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kgpgcertmanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kworldclock ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/KRegExpEditor ; rm -rf common )
